##  Project Reports
In the Reporting section you have several Project Reports:
### Project Portfolio
Your entry point into Project reporting, the Project Portfolio Report allows you to visualize and act based on Project Risk vs. Business Value.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274b5edc7a441014b31efc9b42347c1e_LowRes.png)
### Project Cost
This report lets you visualize Project Costs next to their corresponding lifecycles.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27569fd17a4410149a9bcc9e85c04daa_LowRes.png)
### Project Landscape
This report gives you an overview on Project and their relations to Business Capabilities. Here you can get different insights depending on the View you select.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274a05047a441014b2f8be5befa31c66_LowRes.png)
### Project Matrix
Here you can dive even deeper into your Projects' data, by selecting two axes and a drilldown relation (i.e. Applications), in addition to several views available.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2753642e7a441014853abdd6e82e51a5_LowRes.png)
Once you have selected the desired View, go to Settings and tweak your report based on what you need to drill down on.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274ff9c67a44101480de896028122378_LowRes.png)
### Project Roadmap
This view is very useful when you want to compare all your Projects' Lifecycles.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275439347a4410149859dd1b93a8de12_LowRes.png)
